Skip to main content

Making engine fast

18 Dec 2022

2:40 am

  • planning to make a major change in the codebase: using enum instead of char for pieces. This is to elude branching in code?
  • added best move tester
  • solved a small bug in move generation

5 am

  • completed the change to enum for pieces
  • maybe the engine is now faster? (because we can now access piece-square tables directly using index without branching)

Comments

Popular posts from this blog

Move generation

1 Jun 2022 after 12 am ditching color output for now reading evening, night more reading modularizing, exceptions 2 Jun 2022 after 12 am started writing this blog lol ### started writing move generation function

Bugfixes in move generation

  27 Jun 2022 3 pm found one corner case: castling is still allowed after rook capture! 9 Jul 2022 afternoon fixed a corner case with promotion (earlier it always promoted to white pieces) 10 Jul 2022 after 12 am fixed a few corner cases with castling (pawns don't threaten blank squares) move count fixed planning to automate perft graphics??? afternoon another castling bug (capturing rook with king cleared only king's castling rights) reason:  else

Faster move generation, Mate in X tests

  24 Dec 2022 1:30 am better  uci  handling, using  istringstream  to parse commands better Mate Score output added Mate in 2, 3, and 4 tests (and they pass! but slow) inlined some functions (maybe faster now?) added Search Type:  Infinite ,  Fixed Depth ,  Time per Move ,  Time per Game ,  Ponder  and  Mate . Not all of them are working yet :') 3 am movelist.reserve(40) : doing this made move generation ~1.5x faster! Now reserving in all vectors. modularized move generation added  get_threats  function